body {
    margin: 0px;
    padding: 0px;
}

#workflow_editor {
    width: 100%;
    height: 100%;
    margin: 0px;
    padding: 0px;
    background: url("++resource++collective.workflowed.stylesheets/grid_10.png");
}

.workflowActions {}

.workflowActions ul {
    display:block;
    list-style-image:none;
    list-style-type:none;
    margin:-0.9em 0 0;
    padding:0 0.5em;
}
.workflowActions li {
    background-color:White;
    display:inline;
    font-size:90%;
    margin:0 0.5em 0 0;
    padding:0 0.25em 0 0;
}
.workflowActions a {
    border:medium none !important;
    text-decoration:none;
}
